@@ -20,7 +20,7 @@ import numpy as np
 
 from .. import (SpectralCube, VaryingResolutionSpectralCube, BooleanArrayMask,
                 FunctionMask, LazyMask, CompositeMask)
-from ..spectral_cube import OneDSpectrum, Projection
+from ..spectral_cube import OneDSpectrum, Projection, VaryingResolutionOneDSpectrum
 from ..np_compat import allbadtonan
 from .. import spectral_axis
 from .. import base_class
@@ -35,6 +35,12 @@ warnings.simplefilter('error', utils.UnsupportedIterationStrategyWarning)
 warnings.simplefilter('error', utils.NotImplementedWarning)
 warnings.simplefilter('error', utils.WCSMismatchWarning)
 
+try:
+    import joblib
+    JOBLIB_INSTALLED = True
+except ImportError:
+    JOBLIB_INSTALLED = False
+
 try:
     import scipy.ndimage
     SCIPYOK = True
@@ -926,6 +932,7 @@ def test_slicing():
                           ((slice(None), slice(None), 1), 2),
                           ((slice(None), slice(None), slice(1)), 3),
                           ((slice(1), slice(1), slice(1)), 3),
+                          ((slice(None, None, -1), slice(None), slice(None)), 3),
                          ])
 def test_slice_wcs(view, naxis):
 
@@ -934,6 +941,28 @@ def test_slice_wcs(view, naxis):
     sl = cube[view]
     assert sl.wcs.naxis == naxis
 
+def test_slice_wcs_reversal():
+    cube, data = cube_and_raw('advs.fits')
+    view = (slice(None,None,-1), slice(None), slice(None))
+
+    rcube = cube[view]
+    rrcube = rcube[view]
+
+    np.testing.assert_array_equal(np.diff(cube.spectral_axis),
+                                  -np.diff(rcube.spectral_axis))
+
+    np.testing.assert_array_equal(rrcube.spectral_axis.value,
+                                  cube.spectral_axis.value)
+    np.testing.assert_array_equal(rcube.spectral_axis.value,
+                                  cube.spectral_axis.value[::-1])
+    np.testing.assert_array_equal(rrcube.world_extrema.value,
+                                  cube.world_extrema.value)
+    # check that the lon, lat arrays are *entirely* unchanged
+    np.testing.assert_array_equal(rrcube.spatial_coordinate_map[0].value,
+                                  cube.spatial_coordinate_map[0].value)
+    np.testing.assert_array_equal(rrcube.spatial_coordinate_map[1].value,
+                                  cube.spatial_coordinate_map[1].value)
+
 def test_spectral_slice_preserve_units():
     cube, data = cube_and_raw('advs.fits')
     cube = cube.with_spectral_unit(u.km/u.s)
@@ -1056,6 +1085,37 @@ def test_twod_numpy(func, how, axis):
     np.testing.assert_equal(proj.value, dproj)
     assert cube.unit == proj.unit
 
+@pytest.mark.parametrize(('func','how','axis'),
+                         itertools.product(('sum','std','max','min','mean'),
+                                           ('slice','cube','auto'),
+                                           ((0,1),(1,2),(0,2))
+                                          ))
+def test_twod_numpy_twoaxes(func, how, axis):
+    # Check that a numpy function returns the correct result when applied along
+    # one axis
+    # This is partly a regression test for #211
+
+    cube, data = cube_and_raw('advs.fits')
+    cube._meta['BUNIT'] = 'K'
+    cube._unit = u.K
+
+    if func == 'mean' and axis != (1,2):
+        with warnings.catch_warnings(record=True) as wrn:
+            spec = getattr(cube,func)(axis=axis, how=how)
+
+        assert 'Averaging over a spatial and a spectral' in str(wrn[-1].message)
+
+    spec = getattr(cube,func)(axis=axis, how=how)
+    # data has a redundant 1st axis
+    dspec = getattr(data.squeeze(),func)(axis=axis)
+
+    if axis == (1,2):
+        assert isinstance(spec, OneDSpectrum)
+        assert cube.unit == spec.unit
+        np.testing.assert_almost_equal(spec.value, dspec)
+    else:
+        np.testing.assert_almost_equal(spec, dspec)
+
 def test_preserves_header_values():
     # Check that the non-WCS header parameters are preserved during projection
 
@@ -1601,7 +1661,8 @@ def test_caching():
     world_extrema_function = base_class.SpatialCoordMixinClass.world_extrema.fget.wrapped_function
 
     assert cube.world_extrema is cube._cache[(world_extrema_function, ())]
-    assert worldextrema == cube.world_extrema
+    np.testing.assert_almost_equal(worldextrema.value,
+                                   cube.world_extrema.value)
 
 def test_spatial_smooth_g2d():
     cube, data = cube_and_raw('adv.fits')
@@ -1676,7 +1737,19 @@ def test_spectral_smooth_median():
     cube_spectral_median = cube.spectral_smooth_median(3)
 
     # Check first slice
-    result = np.array([ 0.77513282,  0.35675333,  0.35675333,  0.98688694])
+    result = np.array([0.77513282,  0.35675333,  0.35675333,  0.98688694])
+
+    np.testing.assert_almost_equal(cube_spectral_median[:,1,1].value, result)
+
+@pytest.mark.skipif('not SCIPYOK')
+@pytest.mark.skipif('not JOBLIB_INSTALLED')
+def test_spectral_smooth_median_4cores():
+    cube, data = cube_and_raw('adv.fits')
+
+    cube_spectral_median = cube.spectral_smooth_median(3, num_cores=4)
+
+    # Check first slice
+    result = np.array([0.77513282,  0.35675333,  0.35675333,  0.98688694])
 
     np.testing.assert_almost_equal(cube_spectral_median[:,1,1].value, result)
 
@@ -1689,3 +1762,34 @@ def test_initialization_from_units():
     newcube = SpectralCube(data=cube.filled_data[:], wcs=cube.wcs)
 
     assert newcube.unit == cube.unit
+
+def test_varyres_spectra():
+    cube, data = cube_and_raw('vda_beams.fits')
+
+    assert isinstance(cube, VaryingResolutionSpectralCube)
+
+    sp = cube[:,0,0]
+
+    assert isinstance(sp, VaryingResolutionOneDSpectrum)
+    assert hasattr(sp, 'beams')
+
+    sp = cube.mean(axis=(1,2))
+
+    assert isinstance(sp, VaryingResolutionOneDSpectrum)
+    assert hasattr(sp, 'beams')
+
+def test_median_2axis():
+    """
+    As of this writing the bottleneck.nanmedian did not accept an axis that is a tuple/list so this test
+    is to make sure that is properly taken into account.
+
+    :return:
+    """
+    cube, data = cube_and_raw('adv.fits')
+
+    cube_median = cube.median(axis=(1, 2))
+
+    # Check first slice
+    result0 = np.array([0.83498009, 0.2606566 , 0.37271531, 0.48548023])
+
+    np.testing.assert_almost_equal(cube_median.value, result0)
